@@ -3,32 +3,45 @@ package MooX::ConfigFromFile::Role::HashMergeLoaded;
 use strict;
 use warnings;
 
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 
 use Hash::Merge;
 
 use Moo::Role;
 
 requires "loaded_config";
+requires "sorted_loaded_config";
+
+has "config_merge_behavior" => (is => "lazy");
+
+sub _build_config_merge_behavior { 'LEFT_PRECEDENT' }
 
 has "config_merger" => (is => "lazy");
 
-sub _build_config_merger { Hash::Merge->new('LEFT_PRECEDENT') }
+sub _build_config_merger
+{
+    my ($class, $params) = @_;
+    defined $params->{config_merge_behavior} or $params->{config_merge_behavior} = $class->_build_config_merge_behavior($params);
+    Hash::Merge->new($params->{config_merge_behavior});
+}
 
-around _build_loaded_config => sub {
+sub _build_merged_loaded_config
+{
     my ($next, $class, $params) = @_;
 
-    defined $params->{raw_loaded_config} or $params->{raw_loaded_config} = $class->_build_raw_loaded_config($params);
-    defined $params->{config_merger}     or $params->{config_merger}     = $class->_build_config_merger($params);
+    defined $params->{sorted_loaded_config} or $params->{sorted_loaded_config} = $class->_build_sorted_loaded_config($params);
+    defined $params->{config_merger}        or $params->{config_merger}        = $class->_build_config_merger($params);
 
     my $config_merged = {};
-    for my $c (map { values %$_ } @{$params->{raw_loaded_config}})
+    for my $c (map { values %$_ } @{$params->{sorted_loaded_config}})
     {
         %$config_merged = %{$params->{config_merger}->merge($config_merged, $c)};
     }
 
     $config_merged;
-};
+}
+
+around _build_loaded_config => \&_build_merged_loaded_config;
 
 1;
 
@@ -77,9 +90,14 @@ of deep structures.
 
 =head1 ATTRIBUTES
 
+=head2 config_merge_behavior
+
+This attribute contains the behavior which will L<config_merger|/config_merger>
+use to merge particular loaded configurations.
+
 =head2 config_merger
 
-This attribute contains the instance of the merger used to merge the
+This attribute contains the instance of L<Hash::Merge> used to merge the
 I<raw_loaded_config> into I<loaded_config>.
 
 =head2 loaded_config
@@ -97,7 +115,7 @@ Jens Rehsack, C<< <rehsack at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015-2017 Jens Rehsack.
+Copyright 2015-2018 Jens Rehsack.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
